asr.test.mocks.gpaw.mpi
=======================

.. automodule:: asr.test.mocks.gpaw.mpi

   
   
   .. rubric:: Functions

   
   .. autofunction:: barrier
   .. autofunction:: broadcast
   .. autofunction:: new_communicator
   .. autofunction:: world_sum
   
   

   
   
   

   
   
   